@@ -241,6 +241,9 @@ def star(
     ".tar.gz" for gzip, ".tar.bz2" for bzip2, ".tar.xz" for lzma and ".tar" for
     no compression.
 
+    The output filename of the tar archive will be $HOME/<bucket name>.tar
+    You can change this with the "-o" option.
+
     Using the "-q" switch will turn off all messages (except errors) apart from
     the final output of the full path of the tar archive that is created.
 
@@ -273,16 +276,23 @@ def star(
     if not quiet:
         print(f"found {len(objects)} files")
     td = tempfile.mkdtemp()
+    copied = 0
+    ignored = 0
     for obj in objects:
+        if "StorageClass" in obj and obj["StorageClass"] in ["GLACIER", "DEEP_ARCHIVE"]:
+            if not quiet:
+                print(f"Not copying {src} as it is Glacier")
+            ignored += 1
+            continue
         src = f"""s3://{bucket}/{objects[obj]["Key"]}"""
         dest = f"""{td}/{os.path.basename(objects[obj]["Key"])}"""
         if verbose and not quiet:
             print(f"""{src} -> {dest}""")
         s3.xcp(src, dest)
+        copied += 1
 
     cwd = os.getcwd()
     os.chdir(td)
-    home = os.environ.get("HOME", "/tmp")
     if compression is None:
         compression = "g"
     if compression == "n":
@@ -297,13 +307,19 @@ def star(
     else:
         ext = "tar.gz"
         wt = "w:gz"
+    home = os.environ.get("HOME", "/tmp")
     if output is None:
-        output = bucket
-    tfn = f"{home}/{output}.{ext}"
+        output = f"{home}/{bucket}"
+    elif not output.startswith("/"):
+        output = f"{cwd}/{output}"
+    tfn = f"{output}.{ext}"
     xtfn = tarfile.open(tfn, wt)
     for fn in glob.iglob("*"):
         xtfn.add(fn)
     xtfn.close()
     os.chdir(cwd)
     shutil.rmtree(td)
+    if not quiet:
+        print(f"copied: {copied}")
+        print(f"ignored: {ignored}")
     print(tfn)
